==> worker_2.11.1.orig.tar.gz: worker-2.11.1/src/aguix/guielement.h <==
/* guielement.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001-2005 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: guielement.h,v 1.19 2005/05/23 18:43:32 ralf Exp $ */

#ifndef GUIELEMENT_H
#define GUIELEMENT_H

#include "aguixdefs.h"
#include "message.h"
#include "widget.h"

class AGUIX;
class AWindow;

class GUIElement : public Widget {
public:
  GUIElement(AGUIX *aguix);
  virtual ~GUIElement();
  GUIElement( const GUIElement &other );
  GUIElement &operator=( const GUIElement &other );

  void move( int nx, int ny );
  void resize( int nw, int nh );
  virtual void redraw();
  virtual void flush();
  virtual const char *getType() const;
  virtual bool isType(const char *type) const;
  virtual void getPos(int*,int*) const;
  virtual void getSize(int*,int*) const;
  virtual void toBack();
  virtual void toFront();
  bool hasWin(Window win) const;
  Window getWindow() const;
  bool isParent(Window) const;
  virtual void paste(unsigned char*);
  virtual void cancelpaste();
  virtual void cancelcut();
  virtual void takeFocus();
  virtual void hide();
  virtual void show();
  bool isVisible() const;
  bool handleMessage(XEvent *,Message *msg);
  bool getAllowTimerEventBreak() const;
  long getNrOfLastEventBreak() const;
  void setNrOfLastEventBreak( long t );
protected:
  Window win;
  static const char *type;

  void doCreateStuff();
  void doDestroyStuff();
  bool visible;
  bool _allow_timerevent_break;
  long _nr_of_last_event_break;
};

#endif

==> worker-2.14.1.tar.gz: worker-2.14.1/src/aguix/guielement.h <==
/* guielement.h
 * This file belongs to Worker, a filemanager for UNIX/X11.
 * Copyright (C) 2001-2005 Ralf Hoffmann.
 * You can contact me at: ralf@boomerangsworld.de
 *   or http://www.boomerangsworld.de/worker
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
/* $Id: guielement.h,v 1.19 2005/05/23 18:43:32 ralf Exp $ */

#ifndef GUIELEMENT_H
#define GUIELEMENT_H

#include "aguixdefs.h"
#include "message.h"
#include "widget.h"
#include "callback.h"
#include <memory>

class AGUIX;
class AWindow;

class GUIElement : public Widget {
public:
  GUIElement(AGUIX *aguix);
  virtual ~GUIElement();
  GUIElement( const GUIElement &other );
  GUIElement &operator=( const GUIElement &other );

  void move( int nx, int ny );
  void resize( int nw, int nh );
  virtual void redraw();
  virtual void flush();
  virtual const char *getType() const;
  virtual bool isType(const char *type) const;
  virtual void getPos(int*,int*) const;
  virtual void getSize(int*,int*) const;
  virtual void toBack();
  virtual void toFront();
  bool hasWin(Window win) const;
  Window getWindow() const;
  bool isParent(Window) const;
  virtual void paste(unsigned char*);
  virtual void cancelpaste();
  virtual void cancelcut();
  virtual void takeFocus();
  virtual void hide();
  virtual void show();
  bool isVisible() const;
  bool handleMessage(XEvent *,Message *msg);
  bool getAllowTimerEventBreak() const;
  long getNrOfLastEventBreak() const;
  void setNrOfLastEventBreak( long t );

  void connect( CallBack *new_cb );
  void setSendMessage( bool nv );
  bool getSendMessage() const;
protected:
  Window win;
  static const char *type;
  bool sendMsg;

  void doCreateStuff();
  void doDestroyStuff();
  bool visible;
  bool _allow_timerevent_break;
  long _nr_of_last_event_break;

  int msgAndCB( std::auto_ptr<AGMessage> msg );
  int callback( int val );
 private:
  CallBack *cb;
};

#endif
